@@ -14,7 +14,7 @@ from .util import *
 from .database import *
 from .bots import *
 from .api import *
-from .overrides import *
+from .events import *
 from .loyalty_ticker import *
 from .disabled_commands import *
 from .duel import *
@@ -22,6 +22,7 @@ from .command_server import start_command_server
 from .modloader import *
 from .disabled_mods import *
 from .data import *
+from .exceptions import *
 from . import builtin_commands
 from . import builtin_mods
 
