@@ -1,16 +1,19 @@
+import asyncio
 import typing
 import re
-from asyncio import StreamWriter, StreamReader
+from asyncio import StreamWriter, StreamReader, get_event_loop
 from .config import cfg
 from .ratelimit import privmsg_ratelimit, whisper_ratelimit
 from .enums import Event
 from textwrap import wrap
+from .events import trigger_event
 
 if typing.TYPE_CHECKING:
     from .bots import BaseBot
 
 PRIVMSG_MAX_LINE_LENGTH = 450
 WHISPER_MAX_LINE_LENGTH = 438
+PRIV_MSG_FORMAT = 'PRIVMSG #{channel} :{line}'
 
 
 class Irc:
@@ -48,23 +51,31 @@ class Irc:
 
         for line in _wrap_message(msg):
             await privmsg_ratelimit(channels.get(channel, DummyChannel(channel)))
-            self.send(f'PRIVMSG #{channel} :{line}')
+            self.send(PRIV_MSG_FORMAT.format(channel=channel, line=line))
 
         # exclude calls from send_whisper being sent to the bots on_privmsg_received event
-        if self.bot and not msg.startswith('/w'):
-            await self.bot.on_privmsg_sent(msg, channel, cfg.nick)
+        if not msg.startswith('/w'):
+            if self.bot:
+                await self.bot.on_privmsg_sent(msg, channel, cfg.nick)
             await trigger_mod_event(Event.on_privmsg_sent, msg, channel, cfg.nick, channel=channel)
+            await trigger_event(Event.on_privmsg_sent, msg, channel, cfg.nick)
 
     async def send_whisper(self, user: str, msg: str):
         """sends a whisper to a user"""
         from .modloader import trigger_mod_event
 
-        await whisper_ratelimit()
-        await self.send_privmsg(user, f'/w {user} {msg}')
+        for line in _wrap_message(f'/w {user} {msg}'):
+            await whisper_ratelimit()
+            self.send(PRIV_MSG_FORMAT.format(channel=user, line=line))
+            # this sleep is necessary to make sure all whispers get sent
+            # without it, consecutive whispers get dropped occasionally
+            # if i find a better fix, will do it instead, but until then, this works
+            await asyncio.sleep(.6)
 
         if self.bot:
             await self.bot.on_whisper_sent(msg, user, cfg.nick)
-            await trigger_mod_event(Event.on_whisper_sent, msg, user, cfg.nick)
+        await trigger_mod_event(Event.on_whisper_sent, msg, user, cfg.nick)
+        await trigger_event(Event.on_whisper_sent, msg, user, cfg.nick)
 
     async def get_next_message(self):
         return (await self.reader.readline()).decode().strip()
